@@ -3,7 +3,7 @@ BEGIN {
   $App::Presto::ArgProcessor::AUTHORITY = 'cpan:BPHILLIPS';
 }
 {
-  $App::Presto::ArgProcessor::VERSION = '0.002';
+  $App::Presto::ArgProcessor::VERSION = '0.003';
 }
 
 # ABSTRACT: Term::ShellUI sub-class
@@ -29,6 +29,14 @@ sub _build_client {
 	return App::Presto->instance->client;
 }
 
+has term => (
+	is       => 'lazy',
+);
+
+sub _build_term {
+	return App::Presto->instance->term;
+}
+
 sub process {
     my $self = shift;
     my $args  = shift;
@@ -59,6 +67,9 @@ sub _expand_param {
 		if($dpath){
 			$replacement = _apply_dpath($replacement, $dpath)
 		}
+	} elsif($param =~ m/^PROMPT($RE{balanced}{-parens => '[]'})($RE{balanced}{-parens => '[]'})?/){
+		my($prompt,$default) = ($1, $2);
+		$replacement = $self->term->readline( substr( $prompt, 1, -1 ) . ' ', ($default ? substr( $default, 1, -1 ) : () ) );
 	}
 	return defined $replacement ? $replacement : $orig;
 }
@@ -100,7 +111,7 @@ App::Presto::ArgProcessor - Term::ShellUI sub-class
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
