@@ -3,7 +3,7 @@ BEGIN {
   $App::Presto::Config::AUTHORITY = 'cpan:BPHILLIPS';
 }
 {
-  $App::Presto::Config::VERSION = '0.002';
+  $App::Presto::Config::VERSION = '0.003';
 }
 
 # ABSTRACT: Manage configuration for a given endpoint
@@ -69,6 +69,11 @@ sub file {
     return sprintf('%s/%s', $self->endpoint_dir, $file);
 }
 
+sub is_set {
+    my $self = shift;
+    my $key  = shift;
+    return exists $self->config->{$key};
+}
 sub set {
     my $self = shift;
     my $key  = shift;
@@ -98,7 +103,7 @@ sub get {
     my $self = shift;
     my $key  = shift;
     return $self->endpoint if $key eq 'endpoint';
-    return $self->config->{$key};
+    return exists $self->config->{$key} ? $self->config->{$key} : undef;
 }
 
 sub keys {
@@ -115,6 +120,20 @@ sub write_config {
     return;
 }
 
+my %DEFAULTS = (
+    binmode        => 'utf8',
+    pretty_printer => 'JSON',
+    deserialize_response => 1,
+);
+sub init_defaults {
+    my $self = shift;
+    foreach my $k(CORE::keys %DEFAULTS){
+        unless($self->is_set($k)){
+            $self->set($k, $DEFAULTS{$k});
+        }
+    }
+    return;
+}
 
 1;
 
@@ -127,7 +146,7 @@ App::Presto::Config - Manage configuration for a given endpoint
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
